@@ -2,7 +2,9 @@
 DSLIBRARY - run your data science code anywhere.
 
 """
-__version__ = "0.0.64"
+__version__ = "0.0.65"
+
+import re
 
 # exceptions
 from .exceptions import *
@@ -98,6 +100,18 @@ def run_model_method(method, dsl=None):
     return ModelRunner(parameters=params).run_method(method)
 
 
+RECOGNIZED_FILE_EXTENSIONS = frozenset((
+    "csv", "tab", "tsv", "csv.zip", "csv.gzip",
+    "json", "xls", "xlsx", "yml", "yaml", "txt",
+    "pq", "parquet", "h5", "hdf"
+))
+PTN_DATA_FILES = re.compile(
+    r'\.(' +
+    '|'.join(f.replace('.', r'\.') for f in RECOGNIZED_FILE_EXTENSIONS)
+    + r')$', re.IGNORECASE
+)
+
+
 # set up default methods
 _DEFAULT = instance()
 get_parameter = _DEFAULT.get_parameter
