@@ -640,7 +640,7 @@ class DSLibrary(object):
                 # pandas > dask
                 content = dask.dataframe.from_pandas(content, npartitions=1)
                 is_dask = True
-            elif is_dask and not use_dask and df_format not in ("csv", "tab", "tsf"):
+            elif is_dask and not use_dask and df_format not in ("csv", "tab", "tsv"):
                 # dask > pandas
                 content = content.compute()
                 is_dask = False
