@@ -3,7 +3,7 @@ import pandas
 import mock
 
 from dslibrary.utils.connect import _process_params, dataframe_to_sql, db_conn_flavor, connect_psycopg2, \
-    connect_to_database, enquote_sql_identifier
+    connect_to_database, enquote_sql_identifier, connect_bigquery
 
 
 class TestConnect(unittest.TestCase):
@@ -114,3 +114,23 @@ class TestConnect(unittest.TestCase):
             connect_psycopg2(host="host", port=1234, username="u", password="p", database="db1", a=123, z="def",
                              service="s1")
 
+    def test_connect_bigquery(self):
+        class Col(object):
+            name = "x"
+        class Rows(object):
+            schema = [Col()]
+            pages = [[[1]]]
+        class Results(object):
+            def result(self, *a, **k):
+                return Rows()
+        class MyConn(object):
+            def query(self, *a, **k):
+                return Results()
+        def conn(service_account: dict, **kwargs):
+            self.assertEqual(service_account, {"etc": 123})
+            return MyConn()
+        with mock.patch("dslibrary.utils.bigq.bgq_connect", conn):
+            cursor = connect_bigquery(host="", database={"etc": 123}).cursor()
+            cursor.execute("SQL")
+            row = cursor.fetchone()
+            self.assertEqual([1], row)
